#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ALLBITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ALLBITS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/allbits.hpp>

#endif
